@@ -6,10 +6,10 @@ def main():
     from cvdastwrapper import fuzzallspecs
     from cvdastwrapper import runall
     
-    print(sys.argv[1:], "argv")
+    #print(sys.argv[1:], "argv")
     if sys.argv[1:]:
         if "--generate-tests" in sys.argv[1:]:
-            print(sys.argv)
+            #print(sys.argv)
             fuzzallspecs.fuzzspecs()                
             return
     runall.main()            
