@@ -22,7 +22,7 @@ from jinja2 import Environment, FileSystemLoader
 from cvdastwrapper import reportutil
 from cvdastwrapper import apispecs
 
-resultrootn = runconfig.dresultdir + "\\" + runconfig.dperadir + "\\"
+resultrootn = runconfig.dresultdir + "/" + runconfig.dperadir + "/"
 ainfofname = runconfig.dainfofname
 global data
 data = {"test_spec_insights": {}, "summary": {}, "metadata_spec": []}
