@@ -86,7 +86,7 @@ def init(inainfofname = "", specdir = ""):
     ''' end for sfname '''
 
     if not runconfig.usecustomlist:
-        print(runconfig.usecustomlist, "üsecustomlist")
+        #print(runconfig.usecustomlist, "usecustomlist")
         runconfig.apispeclist = apispecs.apispeclist
     
     resultrootn = runconfig.dresultdir + "/" + runconfig.dperadir + "/"
