@@ -660,7 +660,7 @@ def sumperattack(csvfname, inspeclist=[], inattacklist=[]):
     rhtml  = "<br><table>\n<tr>\n"
     rhtml += "<th rowspan=\"2\">Spec Name</th>\n"
     rhtml += "<th rowspan=\"2\">N of APIs</th>\n"
-    rhtml += "<th colspan=\"4\">N of APIs with Issues By Priority</th>\n"
+    rhtml += "<th colspan=\"4\">N of API Issues By Priority</th>\n"
     rhtml += "<th rowspan=\"2\">N of Different Attack Types Tested</th>\n"
     rhtml += "<th colspan=\"2\">N of Attack Tests By Passed/Failed Results</th>\n"
     rhtml += "</tr><tr>\n"
@@ -690,7 +690,7 @@ def sumperattack(csvfname, inspeclist=[], inattacklist=[]):
     inputfilenum = 0
     for spec in thespeclist:
         spec = spec.lower()   # important, cannonical form of spec all lower case
-        print(spec)
+        #print(spec)
         if not os.path.exists(resultrootn+spec):
             print("-- Failed to generate summary report: %s does not exist. " % resultrootn+spec)
             return ""
@@ -755,7 +755,7 @@ def sumperattack(csvfname, inspeclist=[], inattacklist=[]):
             failedTestReport(failedr, spec, tests)
             an += 1
         ''' end for a in attacks '''
-        print(failedr)
+        #print(failedr)
         detailhtml += "<tr><td rowspan=\""+ str(srow) + "\">"+spec+"</td>\n"
         detailhtml += dahtml
         sumr[spec]["tatype"] = an
